Index: /trunk/SophyaPI/PI/parradapter.cc
===================================================================
--- /trunk/SophyaPI/PI/parradapter.cc	(revision 556)
+++ /trunk/SophyaPI/PI/parradapter.cc	(revision 557)
@@ -156,5 +156,5 @@
 int n0 = 0;
 
-if (min >= max) { min = -9.e19; max = 9.e19; }
+if (min >= max) { min = -9.e69; max = 9.e69; }
 double minpix = max;
 double maxpix = min; 
@@ -220,5 +220,5 @@
 int_4 *q;
 
-double MINDYNAMIC = 1.e-8;          /* Gamme dynamique minimale (MaxAff-MinAff)*/
+double MINDYNAMIC = 1.e-48;          /* Gamme dynamique minimale (MaxAff-MinAff)*/
 double FRACPIC = 0.6065;            /*  Valeur de exp(-0.5)   */
 
Index: /trunk/SophyaPI/PI/picmapview.h
===================================================================
--- /trunk/SophyaPI/PI/picmapview.h	(revision 556)
+++ /trunk/SophyaPI/PI/picmapview.h	(revision 557)
@@ -23,6 +23,6 @@
   virtual long	  kind() {return ClassId; }
 
-  void            SetColMap(PIColorMap* cmp=NULL, float min=1., float max=-1., bool refr=true);
-  void            SetColMapId(CMapId cmapid, float min=1., float max=-1., bool refr=true);
+  void            SetColMap(PIColorMap* cmp=NULL, double min=1., double max=-1., bool refr=true);
+  void            SetColMapId(CMapId cmapid, double min=1., double max=-1., bool refr=true);
 
 // Traitement des evenements   
@@ -33,5 +33,5 @@
 protected:
   PIColorMap* cmap;
-  float vmin, vmax;
+  double vmin, vmax;
 };
 
Index: /trunk/SophyaPI/PI/piimage.cc
===================================================================
--- /trunk/SophyaPI/PI/piimage.cc	(revision 556)
+++ /trunk/SophyaPI/PI/piimage.cc	(revision 557)
@@ -136,5 +136,5 @@
 AddDrawer(mdrw, true, false, false);
 
-SetLut(0., 32000., kLutType_Lin, 0, false);
+SetLut(-9.e19, 9.e19, kLutType_Lin, 0, false);
 SetColMapId(CMAP_COLRJ32);
 // pour le copier-coller
@@ -432,4 +432,7 @@
   int nbsig = lauto;  
   double fracmax = 1. - 0.05*nbsig;
+  int nbnul, nbsat;
+  double moy, sig;
+  img->CheckDyn(min, max, moy, sig, nbnul, nbsat);
   img->ComputeLut_PicHisto(min, max, nbsig, fracmax);
   }
Index: /trunk/SophyaPI/PI/piimgtools.h
===================================================================
--- /trunk/SophyaPI/PI/piimgtools.h	(revision 556)
+++ /trunk/SophyaPI/PI/piimgtools.h	(revision 557)
@@ -35,5 +35,5 @@
   PILabel* mOlb[2];
   PIScale* mSc[2];
-  float min_lut,max_lut;
+  double min_lut,max_lut;
 // Pour la couleur et le zoom
   PIOptMenu* mOptzc[2];

Index: /trunk/SophyaPI/PI/picmapview.cc
===================================================================
--- /trunk/SophyaPI/PI/picmapview.cc	(revision 556)
+++ /trunk/SophyaPI/PI/picmapview.cc	(revision 557)
@@ -56,8 +56,8 @@
 // long  kind()
 //	Retourne PICMapView::ClassId .
 // void   SetColMap(PIColorMap* cmp=NULL, float min=1., float max=-1., bool refr=true)
 //	Choix de la table de couleur et valeurs min et max. Si "refr==true",
 //	la méthode "Refresh()" est appelée.
 // void  SetColMapId(CMapId cmapid, float min=1., float max=-1., bool refr=true)
 //	Choix de la table de couleur en utilisant le "CMapId" et 
 //	définition des valeurs min et max. Si "refr==true",
@@ -66,5 +66,5 @@
  
 /* --Methode-- */
-void PICMapView::SetColMap(PIColorMap* cmp, float min, float max, bool refr)
+void PICMapView::SetColMap(PIColorMap* cmp, double min, double max, bool refr)
 {
   if (cmp == NULL)   { 
@@ -76,6 +76,6 @@
     }
   if ( cmap && (cmp->Type() == cmap->Type()) && (cmp->Type() != CMAP_OTHER) 
-       && ((vmin-min) < 1.e-19) &&  ((vmin-min) > -1.e-19) &&
-       ((vmax-max) < 1.e-19) &&  ((vmax-max) > -1.e-19) )  return;
+       && ((vmin-min) < 1.e-69) &&  ((vmin-min) > -1.e-69) &&
+       ((vmax-max) < 1.e-69) &&  ((vmax-max) > -1.e-69) )  return;
   if (cmap) delete cmap;
   cmap = new PIColorMap(*cmp);
@@ -86,9 +86,9 @@
 
 /* --Methode-- */
-void PICMapView::SetColMapId(CMapId cmapid, float min, float max, bool refr)
+void PICMapView::SetColMapId(CMapId cmapid, double min, double max, bool refr)
 {
   if ( cmap && (cmapid == cmap->Type()) && (cmapid != CMAP_OTHER) 
-       && ((vmin-min) < 1.e-19) &&  ((vmin-min) > -1.e-19) &&
-       ((vmax-max) < 1.e-19) &&  ((vmax-max) > -1.e-19) )  return;
+       && ((vmin-min) < 1.e-69) &&  ((vmin-min) > -1.e-69) &&
+       ((vmax-max) < 1.e-69) &&  ((vmax-max) > -1.e-69) )  return;
   if (cmap) delete cmap;
   cmap = new PIColorMap(cmapid);
@@ -56,8 +56,8 @@
 // long  kind()
 //	Retourne PICMapView::ClassId .
-// void   SetColMap(PIColorMap* cmp=NULL, float min=1., float max=-1., bool refr=true)
+// void   SetColMap(PIColorMap* cmp=NULL, double min=1., double max=-1., bool refr=true)
 //	Choix de la table de couleur et valeurs min et max. Si "refr==true",
 //	la méthode "Refresh()" est appelée.
@@ -56,8 +56,8 @@
 //	Choix de la table de couleur et valeurs min et max. Si "refr==true",
 //	la méthode "Refresh()" est appelée.
-// void  SetColMapId(CMapId cmapid, float min=1., float max=-1., bool refr=true)
+// void  SetColMapId(CMapId cmapid, double min=1., double max=-1., bool refr=true)
 //	Choix de la table de couleur en utilisant le "CMapId" et 
 //	définition des valeurs min et max. Si "refr==true",